Package: dexter
Type: Package
Title: Data Management and Analysis of Tests
Version: 1.8.1
Authors@R: c(
    person("Gunter","Maris", role="aut"),
    person("Timo","Bechger", role="aut"),
    person("Jesse","Koops", role=c("aut","cre"), email="jesse.koops@cito.nl"),
    person("Ivailo","Partchev", role="aut"))
Maintainer: Jesse Koops <jesse.koops@cito.nl>
Description: A system for the management, assessment, and psychometric analysis of data from educational and psychological tests. 
License: LGPL-3
URL: https://dexter-psychometrics.github.io/dexter/
BugReports: https://github.com/dexter-psychometrics/dexter/issues
Encoding: UTF-8
LazyData: yes
Depends: R (>= 4.1)
Imports: RSQLite (>= 2.2.7), DBI (>= 1.0.0), MASS (>= 7.3), tidyr (>=
        1.2.0), rlang (>= 1.0.0), dplyr (>= 1.1.0), Rcpp (>= 1.0.1),
        RcppArmadillo (>= 0.12.6.6.0), graphics, grDevices, methods,
        utils
LinkingTo: Rcpp, RcppArmadillo (>= 0.12.6.6.0), dqrng, BH
Suggests: knitr, rmarkdown, latticeExtra, testthat, Cairo, cli,
        parallel
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-07-24 08:15:15 UTC; jessek
Author: Gunter Maris [aut],
  Timo Bechger [aut],
  Jesse Koops [aut, cre],
  Ivailo Partchev [aut]
Repository: CRAN
Date/Publication: 2026-07-24 10:30:02 UTC
Built: R 4.6.1; aarch64-apple-darwin23; 2026-07-24 11:27:18 UTC; unix
Archs: dexter.so.dSYM
